@@ -33,7 +33,6 @@
 // - use more HildonCaption in settings dialog?
 //   - checkbox buttons look fine without Caption
 //   - PickerButton could use a larger font
-// - add reset button to restore default settings
 // - check settings dialog for object/memory leaks
 // - check return code from g_timeout_add_seconds/g_signal_connect
 // - does g_source_remove destroy the source or does it leak?
@@ -72,7 +71,7 @@
 
 
 
-// #define DEBUG
+//#define DEBUG
 
 #ifdef DEBUG
 
@@ -452,9 +451,10 @@ show_status_banner (CCCHHDoorIsDesktopWidget *self)
 				(self->connected) ? ("") : _("(offline)"));
 				break;
 		default:
-			text = g_strdup_printf(("%s %s"),
+			text = g_strdup_printf(("%s %s %s"),
 				_("CCCHH: Unknown"),
-				(self->connected) ? ("") : _("(offline)"));
+				(self->connected) ? ("") : _("(offline)"),
+				(self->too_old) ? _("(data too old)") : (""));
 				break;
 	}
 
@@ -491,6 +491,15 @@ force_redraw (CCCHHDoorIsDesktopWidget *self)
 	gdk_region_destroy (region);
 }
 
+static void
+force_redraw_window (GtkWindow *window)
+{
+	g_debug(WIDGET_NAME": force_redraw_window()");
+
+	// process expose event
+	gdk_window_process_updates (window, TRUE);
+}
+
 
 
 
@@ -729,10 +738,12 @@ fetch_update_process (CCCHHDoorIsDesktopWidget *self, dooris_state_t new_state,
 	self->current_state = new_state;
 	self->last_change_ts = new_change_ts;
 	self->last_report_ts = new_report_ts;
+	self->too_old = FALSE;
 
 	time (&timenow);
 	if (timenow != -1 && self->last_report_ts && (timenow - self->last_report_ts) > REPORT_TIMEOUT) {
 		g_message(WIDGET_NAME": fetch_update_process: last_report_ts too old, forcing state to DOORIS_FNORD");
+		self->too_old = TRUE;
 		self->current_state = DOORIS_FNORD;
 	}
 
@@ -1048,7 +1059,6 @@ ccchh_dooris_desktop_widget_on_settings_dialog_response (GtkDialog *dialog,
 	g_debug(WIDGET_NAME": ccchh_dooris_desktop_widget_on_settings_dialog_response()");
 
 	// only use new settings if user pressed the OK button
-	// TODO: add reset button to restore defaults
 	if (response_id == GTK_RESPONSE_ACCEPT) {
 		g_debug(WIDGET_NAME": response accept");
 
@@ -1120,20 +1130,48 @@ ccchh_dooris_desktop_widget_on_settings_dialog_response (GtkDialog *dialog,
 		}
 
 		save_settings(self);
+
+		gtk_widget_destroy (self->settings_window);
+		// TODO: does this leak any object references such as GtkSizeGroup
+		// or HildonCaption?
+		// isn't there a better way to this? array+memset?
+		self->settings_window = NULL;
+		self->url_entry = NULL;
+		self->update_picker = NULL;
+		self->notify_button = NULL;
+		self->connection_button = NULL;
+		self->connforce_button = NULL;
+
+	} else if (response_id == GTK_RESPONSE_NO) {
+		g_debug(WIDGET_NAME": restoring default configuration");
+
+		gtk_entry_set_text(GTK_ENTRY(self->url_entry), "http://dooris.koalo.de/door.txt");
+//		gtk_entry_set_text(GTK_ENTRY(self->url_entry), "http://formularfetischisten.de/~packbart/temp/door.txt");
+
+		hildon_check_button_set_active(HILDON_CHECK_BUTTON(self->notify_button), TRUE);
+		hildon_check_button_set_active(HILDON_CHECK_BUTTON(self->connforce_button), TRUE);
+		hildon_check_button_set_active(HILDON_CHECK_BUTTON(self->connection_button), TRUE);
+
+		hildon_touch_selector_set_active(
+			hildon_picker_button_get_selector(HILDON_PICKER_BUTTON(self->update_picker)),
+			0, 4);
+
+		hildon_button_set_value(HILDON_BUTTON (self->update_picker), "23");
+
 	} else {
 		g_debug(WIDGET_NAME": not saving new settings, response ID was %i", response_id);
-	}
 
-	gtk_widget_destroy (self->settings_window);
-	// TODO: does this leak any object references such as GtkSizeGroup
-	// or HildonCaption?
-	// isn't there a better way to this? array+memset?
-	self->settings_window = NULL;
-	self->url_entry = NULL;
-	self->update_picker = NULL;
-	self->notify_button = NULL;
-	self->connection_button = NULL;
-	self->connforce_button = NULL;
+		gtk_widget_destroy (self->settings_window);
+		// TODO: does this leak any object references such as GtkSizeGroup
+		// or HildonCaption?
+		// isn't there a better way to this? array+memset?
+		self->settings_window = NULL;
+		self->url_entry = NULL;
+		self->update_picker = NULL;
+		self->notify_button = NULL;
+		self->connection_button = NULL;
+		self->connforce_button = NULL;
+	}
 }
 
 
@@ -1178,6 +1216,7 @@ ccchh_dooris_desktop_widget_on_show_settings (GtkWidget *widget G_GNUC_UNUSED,
 			_("CCCHH DoorIs Widget Settings"), 
 			NULL /* parent window */, 
 			GTK_DIALOG_NO_SEPARATOR /* flags */, 
+			_("Defaults"), GTK_RESPONSE_NO,
 			GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
 			NULL);
 		// call dialog_response() on close
@@ -1477,6 +1516,7 @@ ccchh_dooris_desktop_widget_init (CCCHHDoorIsDesktopWidget *self)
 
 	self->last_change_ts = 0L;
 	self->last_report_ts = 0L;
+	self->too_old = FALSE;
 
 	// set image to NULL, first expose event will then call update()
 	self->image_current = NULL;
